def get_permission_sets(account_id: str, items: dict) -> dict: ...
def read_users(data: list) -> list: ...
def read_groups(data: list) -> list: ...
def read_permission_sets(data: list) -> list: ...
def get_all_permission_set_arns(sso_admin, sso_instance_arn: str) -> list: ...
def get_user_id(user_name: str, items: dict) -> dict: ...
def get_group_id(group_name: str, items: dict) -> dict: ...
def get_permission_set_arn(permission_set_name: str, items: dict) -> dict: ...
def process_json(file_name: str, user_ids: list, group_ids: list, permission_set_arns: list) -> str: ...
def process_mappings(data: list, file_name: str, sso_mappings_old_user_heading: str, sso_mappings_new_user_heading: str, sso_mappings_old_group_pattern: str, sso_mappings_new_group_pattern: str) -> str: ...
def assign_permission_sets(account_id: str, items: dict) -> list: ...
def assign_permission_sets_dry_run(account_id: str, items: dict) -> list: ...
def update_user_name(user_dict: dict, items: dict) -> dict: ...
def update_group_name(group_dict: dict, items: dict) -> dict: ...
def get_group_memberships(group_name: str, items: dict) -> dict: ...
def main() -> None: ...
