#!/usr/bin/env python3
# -*- coding: latin-1 -*-

"""
Run AWS administrative scripts.

Prerequisite steps:
1. Copy the extras/parameters.ini file to your current working directory.
2. Update the file with the necessary values.

Example usage:
```python
from aws_administrator import aws_sso_get
aws_sso_get.aws_sso_get()
```
"""
import __init__
