from . import helper_aws_entrypoint as helper_aws_entrypoint, helper_common as helper_common

def get_sgs(account_id: str, items: dict) -> dict: ...
def get_vpcs(account_id: str, items: dict) -> dict: ...
def main() -> None: ...
