from .helper_parameters import *

def auth(auth_method: str, profile_name: str, access_key_id: str, secret_access_key: str, sso_url: str, sso_role_name: str, sso_account_id: str): ...
def crawler(session, accounts_list_src: str, accounts: str, ou: str, statuses: str) -> list: ...
def enter_aws() -> dict: ...
def account_client_auth(account_id: str, items: dict, service: str): ...
def main() -> None: ...
